@@ -1,6 +1,6 @@
 from pyo import *
 
-cats = OBJECTS_TREE['PyoObjectBase']['PyoTableObject']
+cats = OBJECTS_TREE["PyoObjectBase"]["PyoTableObject"]
 
 cats.sort()
 
@@ -25,4 +25,3 @@ with open("tables.rst", "w") as f:
     f.write(module % "Tables")
     for obj in cats:
         f.write(template % (obj, obj))
-
