@@ -92,11 +92,14 @@ INLINE PyThreadState * pyo_new_interpreter(float sr, int bufsize, int chnls) {
     /* On MacOS, trying to import wxPython in embedded python hang the process. */
     PyRun_SimpleString("import os; os.environ['PYO_GUI_WX'] = '0'");
 
+    /* Force embedded audio server. */
+    PyRun_SimpleString("os.environ['PYO_SERVER_AUDIO'] = 'embedded'");
+
     /* Set the default BPM (60 beat per minute). */
     PyRun_SimpleString("BPM = 60.0");
 
     PyRun_SimpleString("from pyo import *");
-    sprintf(msg, "_s_ = Server(%f, %d, %d, 1, 'embedded')", sr, chnls, bufsize);
+    sprintf(msg, "_s_ = Server(%f, %d, %d, 1)", sr, chnls, bufsize);
     PyRun_SimpleString(msg);
     PyRun_SimpleString("_s_.boot()\n_s_.start()\n_s_.setServer()");
     PyRun_SimpleString("_server_id_ = _s_.getServerID()");
@@ -296,11 +299,15 @@ INLINE void pyo_end_interpreter(PyThreadState *interp) {
     PyRun_SimpleString("_s_.setServer()\n_s_.stop()\n_s_.shutdown()");
     PyEval_ReleaseThread(interp);
 
+    PyGILState_STATE state = PyGILState_Ensure();
+
     /* End the sub-interpreter. */
     PyThreadState* _ts = PyThreadState_Swap(interp);
     Py_EndInterpreter(interp);
     PyThreadState_Swap(_ts);
 
+    PyGILState_Release(state);
+
 #if !defined(_WIN32)
     if (libpython_handle != NULL) {
         dlclose(libpython_handle);
