@@ -18,10 +18,17 @@
  * License along with pyo.  If not, see <http://www.gnu.org/licenses/>.   *
  *************************************************************************/
 
+#ifndef _PYOMODULE_H
+#define _PYOMODULE_H
+
 #include "Python.h"
+
+#include <stdint.h>
 #include <math.h>
 
-#define PYO_VERSION "1.0.3"
+#define PYO_VERSION "1.0.4"
+
+typedef Py_ssize_t T_SIZE_T;
 
 #ifndef __MYFLT_DEF
 #define __MYFLT_DEF
@@ -32,10 +39,12 @@
 #define FLOAT_VALUE f
 #define TYPE_F "f"
 #define TYPE_F_I "f|i"
+#define TYPE_F_N "f|n"
 #define TYPE__IF "|if"
 #define TYPE__FF "|ff"
 #define TYPE__IFF "|iff"
 #define TYPE__FII "|fii"
+#define TYPE__FIN "|fin"
 #define TYPE_F_II "f|ii"
 #define TYPE__FFF "|fff"
 #define TYPE_F_FFF "f|fff"
@@ -77,7 +86,9 @@
 #define TYPE_F_O "f|O"
 #define TYPE_F_OF "f|Of"
 #define TYPE__OFFI "|Offi"
+#define TYPE__OFFN "|Offn"
 #define TYPE__OFII "|Ofii"
+#define TYPE__OFIN "|Ofin"
 #define TYPE__OFIOO "|OfiOO"
 #define TYPE__OOFOO "|OOfOO"
 #define TYPE__FIIOO "|fiiOO"
@@ -95,6 +106,7 @@
 #define TYPE_O_OOOFOO "O|OOOfOO"
 #define TYPE_OO_OOOIFOO "OO|OOOifOO"
 #define TYPE__FFFFIFI "|ffffifi"
+#define TYPE__FFFFIFN "|ffffifn"
 
 #define SF_WRITE sf_write_float
 #define SF_READ sf_read_float
@@ -123,10 +135,12 @@
 #define FLOAT_VALUE d
 #define TYPE_F "d"
 #define TYPE_F_I "d|i"
+#define TYPE_F_N "d|n"
 #define TYPE__IF "|id"
 #define TYPE__FF "|dd"
 #define TYPE__IFF "|idd"
 #define TYPE__FII "|dii"
+#define TYPE__FIN "|din"
 #define TYPE_F_II "d|ii"
 #define TYPE__FFF "|ddd"
 #define TYPE_F_FFF "d|ddd"
@@ -168,7 +182,9 @@
 #define TYPE_F_O "d|O"
 #define TYPE_F_OF "d|Od"
 #define TYPE__OFFI "|Oddi"
+#define TYPE__OFFN "|Oddn"
 #define TYPE__OFII "|Odii"
+#define TYPE__OFIN "|Odin"
 #define TYPE__OFIOO "|OdiOO"
 #define TYPE__OOFOO "|OOdOO"
 #define TYPE__FIIOO "|diiOO"
@@ -186,6 +202,7 @@
 #define TYPE_O_OOOFOO "O|OOOdOO"
 #define TYPE_OO_OOOIFOO "OO|OOOidOO"
 #define TYPE__FFFFIFI "|ddddidi"
+#define TYPE__FFFFIFN "|ddddidn"
 
 #define SF_WRITE sf_write_double
 #define SF_READ sf_read_double
@@ -208,8 +225,8 @@
 #define MYEXP exp
 #define MYROUND round
 
-#endif
-#endif
+#endif // USE_DOUBLE
+#endif // __MYFLT_DEF
 
 #ifdef COMPILE_EXTERNALS
 #include "externalmodule.h"
@@ -611,7 +628,7 @@ extern PyTypeObject MMLZStreamType;
     PyObject_HEAD \
     PyObject *server; \
     TableStream *tablestream; \
-    int size; \
+    T_SIZE_T size; \
     MYFLT *data;
 
 #define pyo_matrix_HEAD \
@@ -626,8 +643,6 @@ extern PyTypeObject MMLZStreamType;
 #define pyo_VISIT \
     if (self->server != NULL) \
         Py_VISIT(self->server); \
-    if (self->stream != NULL) \
-        Py_VISIT(self->stream); \
     Py_VISIT(self->mul); \
     Py_VISIT(self->mul_stream); \
     Py_VISIT(self->add); \
@@ -636,53 +651,40 @@ extern PyTypeObject MMLZStreamType;
 #define pyo_table_VISIT \
     if (self->server != NULL) \
         Py_VISIT(self->server); \
-    if (self->tablestream != NULL) \
-        Py_VISIT(self->tablestream); \
 
 #define pyo_matrix_VISIT \
     if (self->server != NULL) \
         Py_VISIT(self->server); \
-    if (self->matrixstream != NULL) \
-        Py_VISIT(self->matrixstream); \
 
 #define pyo_CLEAR \
     if (self->server != NULL) { \
         Py_DECREF(self->server); \
         self->server = NULL; \
     } \
-    if (self->stream != NULL) \
-        Py_CLEAR(self->stream); \
     Py_CLEAR(self->mul); \
-    Py_CLEAR(self->mul_stream); \
     Py_CLEAR(self->add); \
-    Py_CLEAR(self->add_stream); \
 
 #define pyo_table_CLEAR \
     if (self->server != NULL) { \
         Py_DECREF(self->server); \
         self->server = NULL; \
     } \
-    if (self->tablestream != NULL) \
-        Py_CLEAR(self->tablestream); \
 
 #define pyo_matrix_CLEAR \
     if (self->server != NULL) { \
         Py_DECREF(self->server); \
         self->server = NULL; \
     } \
-    if (self->matrixstream != NULL) \
-        Py_CLEAR(self->matrixstream); \
 
 #define pyo_DEALLOC \
     if (self->server != NULL && self->stream != NULL) \
         Server_removeStream((Server *)self->server, Stream_getStreamId(self->stream)); \
-    free(self->data); \
+    PyMem_RawFree(self->data); \
 
 #define ASSERT_ARG_NOT_NULL \
-	if (arg == NULL) { \
-		Py_INCREF(Py_None); \
-		return Py_None; \
-	}
+    if (arg == NULL) { \
+        Py_RETURN_NONE; \
+    }
 
 /* INIT INPUT STREAM */
 #define INIT_INPUT_STREAM \
@@ -713,11 +715,19 @@ extern PyTypeObject MMLZStreamType;
     Py_INCREF(self->server); \
     self->mul = PyFloat_FromDouble(1); \
     self->add = PyFloat_FromDouble(0); \
-    self->bufsize = PyInt_AsLong(PyObject_CallMethod(self->server, "getBufferSize", NULL)); \
-    self->sr = PyFloat_AsDouble(PyObject_CallMethod(self->server, "getSamplingRate", NULL)); \
-    self->nchnls = PyInt_AsLong(PyObject_CallMethod(self->server, "getNchnls", NULL)); \
-    self->ichnls = PyInt_AsLong(PyObject_CallMethod(self->server, "getIchnls", NULL)); \
-    self->data = (MYFLT *)realloc(self->data, (self->bufsize) * sizeof(MYFLT)); \
+    PyObject *bufobj = PyObject_CallMethod(self->server, "getBufferSize", NULL); \
+    self->bufsize = PyLong_AsLong(bufobj); \
+    Py_DECREF(bufobj); \
+    PyObject *srobj = PyObject_CallMethod(self->server, "getSamplingRate", NULL); \
+    self->sr = PyFloat_AsDouble(srobj); \
+    Py_DECREF(srobj); \
+    PyObject *nchobj = PyObject_CallMethod(self->server, "getNchnls", NULL); \
+    self->nchnls = PyLong_AsLong(nchobj); \
+    Py_DECREF(nchobj); \
+    PyObject *ichobj = PyObject_CallMethod(self->server, "getIchnls", NULL); \
+    self->ichnls = PyLong_AsLong(ichobj); \
+    Py_DECREF(ichobj); \
+    self->data = (MYFLT *)PyMem_RawRealloc(self->data, (self->bufsize) * sizeof(MYFLT)); \
     for (i=0; i<self->bufsize; i++) \
         self->data[i] = 0.0; \
     MAKE_NEW_STREAM(self->stream, &StreamType, NULL); \
@@ -740,13 +750,13 @@ extern PyTypeObject MMLZStreamType;
 
 /* Set data */
 #define SET_TABLE_DATA \
-    int i; \
+    T_SIZE_T i; \
     if (! PyList_Check(arg)) { \
         PyErr_SetString(PyExc_TypeError, "The data must be a list of floats."); \
         return PyInt_FromLong(-1); \
     } \
-    self->size = PyList_Size(arg); \
-    self->data = (MYFLT *)realloc(self->data, (self->size+1) * sizeof(MYFLT)); \
+    self->size = (T_SIZE_T)PyList_Size(arg); \
+    self->data = (MYFLT *)PyMem_RawRealloc(self->data, (self->size+1) * sizeof(MYFLT)); \
     TableStream_setSize(self->tablestream, self->size+1); \
  \
     for (i=0; i<(self->size); i++) { \
@@ -755,8 +765,7 @@ extern PyTypeObject MMLZStreamType;
     self->data[self->size] = self->data[0]; \
     TableStream_setData(self->tablestream, self->data); \
  \
-    Py_INCREF(Py_None); \
-    return Py_None; \
+    Py_RETURN_NONE; \
 
 #define SET_MATRIX_DATA \
     int i, j; \
@@ -766,16 +775,19 @@ extern PyTypeObject MMLZStreamType;
         PyErr_SetString(PyExc_TypeError, "The data must be a list of list of floats."); \
         return PyInt_FromLong(-1); \
     } \
+    for (i = 0; i < (self->height + 1); i++) { \
+        PyMem_RawFree(self->data[i]); \
+    } \
     self->height = PyList_Size(arg); \
     self->width = PyList_Size(PyList_GetItem(arg, 0)); \
-    self->data = (MYFLT **)realloc(self->data, (self->height + 1) * sizeof(MYFLT)); \
+    self->data = (MYFLT **)PyMem_RawRealloc(self->data, (self->height + 1) * sizeof(MYFLT *)); \
     for (i=0; i<(self->height+1); i++) { \
-        self->data[i] = (MYFLT *)realloc(self->data[i], (self->width + 1) * sizeof(MYFLT)); \
+        self->data[i] = (MYFLT *)PyMem_RawMalloc((self->width + 1) * sizeof(MYFLT)); \
     } \
     MatrixStream_setWidth(self->matrixstream, self->width); \
     MatrixStream_setHeight(self->matrixstream, self->height); \
  \
-    for(i=0; i<self->height; i++) { \
+    for (i=0; i<self->height; i++) { \
         innerlist = PyList_GetItem(arg, i); \
         for (j=0; j<self->width; j++) { \
             self->data[i][j] = PyFloat_AsDouble(PyList_GET_ITEM(innerlist, j)); \
@@ -784,20 +796,21 @@ extern PyTypeObject MMLZStreamType;
  \
     MatrixStream_setData(self->matrixstream, self->data); \
  \
-    Py_INCREF(Py_None); \
-    return Py_None; \
+    Py_RETURN_NONE; \
 
 #define COPY \
-    int i; \
-    MYFLT *tab = TableStream_getData((TableStream *)PyObject_CallMethod((PyObject *)arg, "getTableStream", "")); \
+    T_SIZE_T i; \
+    PyObject *table = PyObject_CallMethod((PyObject *)arg, "getTableStream", ""); \
+    MYFLT *tab = TableStream_getData((TableStream *)table); \
     for (i=0; i<self->size; i++) { \
         self->data[i] = tab[i]; \
     } \
     self->data[self->size] = self->data[0]; \
+    Py_DECREF(table); \
     Py_RETURN_NONE; \
 
 #define TABLE_ADD \
-    int i, tabsize; \
+    T_SIZE_T i, tabsize; \
     MYFLT x = 0.0; \
     MYFLT *list = NULL; \
     PyObject *table = NULL; \
@@ -812,6 +825,7 @@ extern PyTypeObject MMLZStreamType;
         table = PyObject_CallMethod((PyObject *)arg, "getTableStream", ""); \
         list = TableStream_getData((TableStream *)table); \
         tabsize = TableStream_getSize((TableStream *)table); \
+        Py_DECREF(table); \
         if (self->size < tabsize) \
             tabsize = self->size; \
         for (i=0; i<tabsize; i++) { \
@@ -819,7 +833,7 @@ extern PyTypeObject MMLZStreamType;
         } \
     } \
     else if (PyList_Check(arg)) { \
-        tabsize = PyList_Size(arg); \
+        tabsize = (T_SIZE_T)PyList_Size(arg); \
         if (self->size < tabsize) \
             tabsize = self->size; \
         for (i=0; i<tabsize; i++) { \
@@ -829,11 +843,10 @@ extern PyTypeObject MMLZStreamType;
  \
     self->data[self->size] = self->data[0]; \
  \
-    Py_INCREF(Py_None); \
-    return Py_None; \
+    Py_RETURN_NONE; \
 
 #define TABLE_SUB \
-    int i, tabsize; \
+    T_SIZE_T i, tabsize; \
     MYFLT x = 0.0; \
     MYFLT *list = NULL; \
     PyObject *table = NULL; \
@@ -848,6 +861,7 @@ extern PyTypeObject MMLZStreamType;
         table = PyObject_CallMethod((PyObject *)arg, "getTableStream", ""); \
         list = TableStream_getData((TableStream *)table); \
         tabsize = TableStream_getSize((TableStream *)table); \
+        Py_DECREF(table); \
         if (self->size < tabsize) \
             tabsize = self->size; \
         for (i=0; i<tabsize; i++) { \
@@ -855,7 +869,7 @@ extern PyTypeObject MMLZStreamType;
         } \
     } \
     else if (PyList_Check(arg)) { \
-        tabsize = PyList_Size(arg); \
+        tabsize = (T_SIZE_T)PyList_Size(arg); \
         if (self->size < tabsize) \
             tabsize = self->size; \
         for (i=0; i<tabsize; i++) { \
@@ -865,11 +879,10 @@ extern PyTypeObject MMLZStreamType;
  \
     self->data[self->size] = self->data[0]; \
  \
-    Py_INCREF(Py_None); \
-    return Py_None; \
+    Py_RETURN_NONE; \
 
 #define TABLE_MUL \
-    int i, tabsize; \
+    T_SIZE_T i, tabsize; \
     MYFLT x = 0.0; \
     MYFLT *list = NULL; \
     PyObject *table = NULL; \
@@ -884,6 +897,7 @@ extern PyTypeObject MMLZStreamType;
         table = PyObject_CallMethod((PyObject *)arg, "getTableStream", ""); \
         list = TableStream_getData((TableStream *)table); \
         tabsize = TableStream_getSize((TableStream *)table); \
+        Py_DECREF(table); \
         if (self->size < tabsize) \
             tabsize = self->size; \
         for (i=0; i<tabsize; i++) { \
@@ -891,7 +905,7 @@ extern PyTypeObject MMLZStreamType;
         } \
     } \
     else if (PyList_Check(arg)) { \
-        tabsize = PyList_Size(arg); \
+        tabsize = (T_SIZE_T)PyList_Size(arg); \
         if (self->size < tabsize) \
             tabsize = self->size; \
         for (i=0; i<tabsize; i++) { \
@@ -901,11 +915,60 @@ extern PyTypeObject MMLZStreamType;
  \
     self->data[self->size] = self->data[0]; \
  \
-    Py_INCREF(Py_None); \
-    return Py_None; \
+    Py_RETURN_NONE; \
+
+#define TABLE_DIV \
+    T_SIZE_T i, tabsize; \
+    MYFLT x = 0.0; \
+    MYFLT *list = NULL; \
+    PyObject *table = NULL; \
+    if (PyNumber_Check(arg)) { \
+        x = PyFloat_AsDouble(arg); \
+        if (x >= 0 && x < 1.0e-24) \
+            x = 1.0e-24; \
+        else if (x < 0 && x > -1.0e-24) \
+            x = -1.0e-24; \
+        for (i=0; i<self->size; i++) { \
+            self->data[i] /= x; \
+        } \
+    } \
+    else if ( PyObject_HasAttrString((PyObject *)arg, "getTableStream") == 1 ) { \
+        Py_XDECREF(table); \
+        table = PyObject_CallMethod((PyObject *)arg, "getTableStream", ""); \
+        list = TableStream_getData((TableStream *)table); \
+        tabsize = TableStream_getSize((TableStream *)table); \
+        Py_DECREF(table); \
+        if (self->size < tabsize) \
+            tabsize = self->size; \
+        for (i=0; i<tabsize; i++) { \
+            x = list[i]; \
+            if (x >= 0 && x < 1.0e-24) \
+                x = 1.0e-24; \
+            else if (x < 0 && x > -1.0e-24) \
+                x = -1.0e-24; \
+            self->data[i] /= x; \
+        } \
+    } \
+    else if (PyList_Check(arg)) { \
+        tabsize = (T_SIZE_T)PyList_Size(arg); \
+        if (self->size < tabsize) \
+            tabsize = self->size; \
+        for (i=0; i<tabsize; i++) { \
+            x = PyFloat_AsDouble(PyList_GET_ITEM(arg, i)); \
+            if (x >= 0 && x < 1.0e-24) \
+                x = 1.0e-24; \
+            else if (x < 0 && x > -1.0e-24) \
+                x = -1.0e-24; \
+            self->data[i] /= x; \
+        } \
+    } \
+ \
+    self->data[self->size] = self->data[0]; \
+ \
+    Py_RETURN_NONE; \
 
 #define SET_TABLE \
-    int i; \
+    T_SIZE_T i; \
     if (arg == NULL) { \
         PyErr_SetString(PyExc_TypeError, "Cannot delete the list attribute."); \
         return PyInt_FromLong(-1); \
@@ -919,23 +982,24 @@ extern PyTypeObject MMLZStreamType;
         PyErr_SetString(PyExc_TypeError, "New table must be of the same size as actual table."); \
         return PyInt_FromLong(-1); \
     } \
-    for(i=0; i<self->size; i++) { \
+    for (i=0; i<self->size; i++) { \
         self->data[i] = PyFloat_AsDouble(PyList_GET_ITEM(arg, i)); \
     } \
     self->data[self->size] = self->data[0]; \
     Py_RETURN_NONE; \
 
 #define GET_TABLE \
-    int i; \
+    T_SIZE_T i; \
     PyObject *samples; \
  \
     samples = PyList_New(self->size); \
-    for(i=0; i<self->size; i++) { \
+    for (i=0; i<self->size; i++) { \
         PyList_SetItem(samples, i, PyFloat_FromDouble(self->data[i])); \
     } \
  \
     return samples;
 
+// TODO: remove in stripped branch...
 #define GET_VIEW_TABLE \
     int i, y, w, h, h2, amp; \
     float step; \
@@ -964,13 +1028,13 @@ extern PyTypeObject MMLZStreamType;
         w = 500; \
         h = 200; \
     } \
-    h2 = h/2; \
+    h2 = h / 2; \
     amp = h2 - 2; \
     step = (float)self->size / (float)(w); \
  \
     samples = PyList_New(w); \
-    for(i=0; i<w; i++) { \
-        y = self->data[(int)(i*step)] * amp + amp + 2; \
+    for (i=0; i<w; i++) { \
+        y = self->data[(T_SIZE_T)(i * step)] * amp + amp + 2; \
         tuple = PyTuple_New(2); \
         PyTuple_SetItem(tuple, 0, PyInt_FromLong(i)); \
         PyTuple_SetItem(tuple, 1, PyInt_FromLong(h-y)); \
@@ -981,7 +1045,7 @@ extern PyTypeObject MMLZStreamType;
 
 /* Table reverse */
 #define REVERSE \
-    int i, j; \
+    T_SIZE_T i, j; \
     MYFLT tmp; \
     j = self->size; \
     for (i=0; i<--j; i++) { \
@@ -990,21 +1054,19 @@ extern PyTypeObject MMLZStreamType;
         self->data[j] = tmp; \
     } \
     self->data[self->size] = self->data[0]; \
-    Py_INCREF(Py_None); \
-    return Py_None; \
+    Py_RETURN_NONE; \
 
 /* Table reset */
 #define TABLE_RESET \
-    int i; \
+    T_SIZE_T i; \
     for (i=0; i<self->size; i++) { \
         self->data[i] = 0.0; \
     } \
-    Py_INCREF(Py_None); \
-    return Py_None; \
+    Py_RETURN_NONE; \
 
 /* Table remove DC */
 #define REMOVE_DC \
-    int i; \
+    T_SIZE_T i; \
     MYFLT x, y, x1, y1; \
     x1 = y1 = 0.0; \
     for (i=0; i<self->size+1; i++) { \
@@ -1013,37 +1075,34 @@ extern PyTypeObject MMLZStreamType;
         x1 = x; \
         self->data[i] = y1 = y; \
     } \
-    Py_INCREF(Py_None); \
-    return Py_None; \
+    Py_RETURN_NONE; \
 
 /* Table amplitude reverse */
 #define INVERT \
-    int i; \
+    T_SIZE_T i; \
     for (i=0; i<self->size+1; i++) { \
         self->data[i] = -self->data[i]; \
     } \
-    Py_INCREF(Py_None); \
-    return Py_None; \
+    Py_RETURN_NONE; \
 
 /* Table positive rectify */
 #define RECTIFY \
-    int i; \
+    T_SIZE_T i; \
     MYFLT x; \
     for (i=0; i<self->size+1; i++) { \
         x = self->data[i]; \
         if (x < 0) \
             self->data[i] = -x; \
     } \
-    Py_INCREF(Py_None); \
-    return Py_None; \
+    Py_RETURN_NONE; \
 
 /* Table rotation */
 #define TABLE_ROTATE \
-    int i, j, pos; \
+    T_SIZE_T i, j, pos; \
     MYFLT tmp; \
     static char *kwlist[] = {"pos", NULL}; \
  \
-    if (! PyArg_ParseTupleAndKeywords(args, kwds, "i", kwlist, &pos)) \
+    if (! PyArg_ParseTupleAndKeywords(args, kwds, "n", kwlist, &pos)) \
         return PyInt_FromLong(-1); \
  \
     pos = -pos; \
@@ -1076,18 +1135,36 @@ extern PyTypeObject MMLZStreamType;
 /* Table copy from table */
 #define TABLE_COPYDATA \
     PyObject *tabletmp; \
-    int i, tabsize, srcpos=0, destpos=0, length=-1; \
+    T_SIZE_T i, tabsize, srcpos=0, destpos=0, length=-1; \
     PyObject *table = NULL; \
     MYFLT *list = NULL; \
     static char *kwlist[] = {"table", "srcpos", "destpos", "length", NULL}; \
  \
-    if (! PyArg_ParseTupleAndKeywords(args, kwds, "O|iii", kwlist, &tabletmp, &srcpos, &destpos, &length)) \
+    if (! PyArg_ParseTupleAndKeywords(args, kwds, "O|nnn", kwlist, &tabletmp, &srcpos, &destpos, &length)) \
         return PyInt_FromLong(-1); \
  \
     if ( PyObject_HasAttrString((PyObject *)tabletmp, "getTableStream") == 1 ) { \
         Py_XDECREF(table); \
         table = PyObject_CallMethod((PyObject *)tabletmp, "getTableStream", ""); \
         tabsize = TableStream_getSize((TableStream *)table); \
+ \
+        if (srcpos < -tabsize || srcpos >= tabsize) { \
+            PyErr_SetString(PyExc_IndexError, "PyoTableObject: Position outside of table boundaries!."); \
+            return PyInt_FromLong(-1); \
+        } \
+    \
+        if (srcpos < 0) \
+            srcpos = tabsize + srcpos; \
+    \
+ \
+        if (destpos < -self->size || destpos >= self->size) { \
+            PyErr_SetString(PyExc_IndexError, "PyoTableObject: Position outside of table boundaries!."); \
+            return PyInt_FromLong(-1); \
+        } \
+    \
+        if (destpos < 0) \
+            destpos = self->size + destpos; \
+ \
         if (length < 0) \
             length = tabsize < self->size ? tabsize : self->size; \
         if ((srcpos + length) > tabsize) \
@@ -1095,6 +1172,7 @@ extern PyTypeObject MMLZStreamType;
         if ((destpos + length) > self->size) \
             length = self->size - destpos; \
         list = TableStream_getData((TableStream *)table); \
+        Py_DECREF(table); \
         for (i=0; i<length; i++) { \
             self->data[destpos+i] = list[srcpos+i]; \
         } \
@@ -1105,7 +1183,7 @@ extern PyTypeObject MMLZStreamType;
 /* Table bipolar gain */
 #define TABLE_BIPOLAR_GAIN \
     MYFLT gpos = 1.0, gneg = 1.0; \
-    int i; \
+    T_SIZE_T i; \
     static char *kwlist[] = {"gpos", "gneg", NULL}; \
  \
     if (! PyArg_ParseTupleAndKeywords(args, kwds, TYPE__FF, kwlist, &gpos, &gneg)) \
@@ -1123,7 +1201,8 @@ extern PyTypeObject MMLZStreamType;
 /* Table power function */
 #define TABLE_POWER \
     MYFLT x, exp; \
-    int i, sign; \
+    T_SIZE_T i; \
+    int sign; \
     static char *kwlist[] = {"exp", NULL}; \
  \
     if (! PyArg_ParseTupleAndKeywords(args, kwds, TYPE_F, kwlist, &exp)) \
@@ -1145,8 +1224,10 @@ extern PyTypeObject MMLZStreamType;
 /* Table one-pole lowpass filter */
 #define TABLE_LOWPASS \
     MYFLT freq, b, c, x, y; \
-    int i; \
-    double sr = PyFloat_AsDouble(PyObject_CallMethod(PyServer_get_server(), "getSamplingRate", NULL)); \
+    T_SIZE_T i; \
+    PyObject *srobj = PyObject_CallMethod(self->server, "getSamplingRate", NULL); \
+    double sr = PyFloat_AsDouble(srobj); \
+    Py_DECREF(srobj); \
     static char *kwlist[] = {"freq", NULL}; \
  \
     if (! PyArg_ParseTupleAndKeywords(args, kwds, TYPE_F, kwlist, &freq)) \
@@ -1165,72 +1246,128 @@ extern PyTypeObject MMLZStreamType;
 /* FADE IN, FADE OUT */
 #define TABLE_FADEIN \
     MYFLT dur, inc; \
-    int i, samp; \
-    double sr = PyFloat_AsDouble(PyObject_CallMethod(PyServer_get_server(), "getSamplingRate", NULL)); \
-    static char *kwlist[] = {"dur", NULL}; \
+    T_SIZE_T i, samp; \
+    int shape = 0; \
+    PyObject *srobj = PyObject_CallMethod(self->server, "getSamplingRate", NULL); \
+    double sr = PyFloat_AsDouble(srobj); \
+    Py_DECREF(srobj); \
+    static char *kwlist[] = {"dur", "shape", NULL}; \
  \
-    if (! PyArg_ParseTupleAndKeywords(args, kwds, TYPE_F, kwlist, &dur)) \
+    if (! PyArg_ParseTupleAndKeywords(args, kwds, TYPE_F_I, kwlist, &dur, &shape)) \
         return PyInt_FromLong(-1); \
  \
-    samp = (int)(dur * sr); \
+    samp = (T_SIZE_T)(dur * sr + 0.5); \
     if (samp < 0 || samp >= self->size) \
         Py_RETURN_NONE; \
  \
     inc = 1.0 / samp; \
-    for (i=0; i<samp; i++) { \
-        self->data[i] = self->data[i] * MYSQRT(inc * i); \
+    switch (shape) \
+    { \
+        case 0: \
+            for (i=0; i<samp; i++) \
+                self->data[i] = self->data[i] * inc * i; \
+            break; \
+        case 1: \
+            for (i=0; i<samp; i++) \
+                self->data[i] = self->data[i] * MYSQRT(inc * i); \
+            break; \
+        case 2: \
+            for (i=0; i<samp; i++) \
+                self->data[i] = self->data[i] * MYSIN(inc * i * PI * 0.5); \
+            break; \
+        case 3: \
+            for (i=0; i<samp; i++) \
+                self->data[i] = self->data[i] * MYPOW(inc * i, 2.0); \
+            break; \
+        default: \
+            for (i=0; i<samp; i++) \
+                self->data[i] = self->data[i] * inc * i; \
     } \
  \
     Py_RETURN_NONE;
 
 #define TABLE_FADEOUT \
     MYFLT dur, inc; \
-    int i, samp; \
-    double sr = PyFloat_AsDouble(PyObject_CallMethod(PyServer_get_server(), "getSamplingRate", NULL)); \
-    static char *kwlist[] = {"dur", NULL}; \
+    T_SIZE_T i, samp; \
+    int shape = 0; \
+    PyObject *srobj = PyObject_CallMethod(self->server, "getSamplingRate", NULL); \
+    double sr = PyFloat_AsDouble(srobj); \
+    Py_DECREF(srobj); \
+    static char *kwlist[] = {"dur", "shape", NULL}; \
  \
-    if (! PyArg_ParseTupleAndKeywords(args, kwds, TYPE_F, kwlist, &dur)) \
+    if (! PyArg_ParseTupleAndKeywords(args, kwds, TYPE_F_I, kwlist, &dur, &shape)) \
         return PyInt_FromLong(-1); \
  \
-    samp = (int)(dur * sr); \
+    samp = (T_SIZE_T)(dur * sr + 0.5); \
     if (samp < 0 || samp >= self->size) \
         Py_RETURN_NONE; \
  \
+    T_SIZE_T size1 = self->size - 1; \
     inc = 1.0 / samp; \
-    for (i=self->size; i>(self->size-samp); i--) { \
-        self->data[i] = self->data[i] * MYSQRT(inc * (self->size - i)); \
+    switch (shape) \
+    { \
+        case 0: \
+            for (i=size1; i>(size1-samp); i--) \
+                self->data[i] = self->data[i] * inc * (size1 - i); \
+            break; \
+        case 1: \
+            for (i=size1; i>(size1-samp); i--) \
+                self->data[i] = self->data[i] * MYSQRT(inc * (size1 - i)); \
+            break; \
+        case 2: \
+            for (i=size1; i>(size1-samp); i--) \
+                self->data[i] = self->data[i] * MYSIN(inc * (size1 - i) * PI * 0.5); \
+            break; \
+        case 3: \
+            for (i=size1; i>(size1-samp); i--) \
+                self->data[i] = self->data[i] * MYPOW(inc * (size1 - i), 2.0); \
+            break; \
+        default: \
+            for (i=size1; i>(size1-samp); i--) \
+                self->data[i] = self->data[i] * inc * (size1 - i); \
     } \
  \
     Py_RETURN_NONE;
 
 /* Normalize */
 #define NORMALIZE \
-	int i; \
-	MYFLT mi, ma, max, ratio; \
-	mi = ma = *self->data; \
-	for (i=1; i<self->size; i++) { \
-		if (mi > *(self->data+i)) \
-			mi = *(self->data+i); \
-		if (ma < *(self->data+i)) \
-			ma = *(self->data+i); \
-	} \
-	if ((mi*mi) > (ma*ma)) \
-		max = MYFABS(mi); \
-	else \
-		max = MYFABS(ma); \
+    T_SIZE_T i; \
+    MYFLT level = 0.99; \
+    MYFLT mi, ma, max, ratio; \
  \
-	if (max > 0.0) { \
-		ratio = 0.99 / max; \
-		for (i=0; i<self->size+1; i++) { \
-			self->data[i] *= ratio; \
-		} \
-	} \
-	Py_INCREF(Py_None); \
-	return Py_None; \
+    static char *kwlist[] = {"level", NULL}; \
+    if (! PyArg_ParseTupleAndKeywords(args, kwds, TYPE_F, kwlist, &level)) \
+        return PyInt_FromLong(-1); \
+ \
+    mi = ma = *self->data; \
+    for (i=1; i<self->size; i++) { \
+        if (mi > *(self->data+i)) \
+            mi = *(self->data+i); \
+        if (ma < *(self->data+i)) \
+            ma = *(self->data+i); \
+    } \
+    if ((mi*mi) > (ma*ma)) \
+        max = MYFABS(mi); \
+    else \
+        max = MYFABS(ma); \
+ \
+    if (max > 0.0) { \
+        ratio = level / max; \
+        for (i=0; i<self->size+1; i++) { \
+            self->data[i] *= ratio; \
+        } \
+    } \
+    Py_RETURN_NONE; \
 
 #define NORMALIZE_MATRIX \
     int i, j; \
+    MYFLT level = 0.99; \
     MYFLT mi, ma, max, ratio; \
+ \
+     static char *kwlist[] = {"level", NULL}; \
+    if (! PyArg_ParseTupleAndKeywords(args, kwds, TYPE_F, kwlist, &level)) \
+        return PyInt_FromLong(-1); \
+ \
     mi = ma = self->data[0][0]; \
     for (i=1; i<self->height; i++) { \
         for (j=1; j<self->width; j++) { \
@@ -1246,48 +1383,116 @@ extern PyTypeObject MMLZStreamType;
         max = MYFABS(ma); \
  \
     if (max > 0.0) { \
-        ratio = 0.99 / max; \
+        ratio = level / max; \
         for (i=0; i<self->height+1; i++) { \
             for (j=0; j<self->width+1; j++) { \
                 self->data[i][j] *= ratio; \
             } \
         } \
     } \
-    Py_INCREF(Py_None); \
-    return Py_None; \
+    Py_RETURN_NONE; \
 
 
 #define TABLE_PUT \
     MYFLT val; \
-    int pos = 0; \
+    T_SIZE_T pos = 0; \
     static char *kwlist[] = {"value", "pos", NULL}; \
  \
-    if (! PyArg_ParseTupleAndKeywords(args, kwds, TYPE_F_I, kwlist, &val, &pos)) \
+    if (! PyArg_ParseTupleAndKeywords(args, kwds, TYPE_F_N, kwlist, &val, &pos)) \
         return PyInt_FromLong(-1); \
  \
-    if (pos >= self->size) \
-        pos = self->size - 1; \
-    else if (pos < 0) \
-        pos = 0; \
+    if (pos < -self->size || pos >= self->size) { \
+        PyErr_SetString(PyExc_IndexError, "PyoTableObject: Position outside of table boundaries!."); \
+        return PyInt_FromLong(-1); \
+    } \
+ \
+    if (pos < 0) \
+        pos = self->size + pos; \
  \
     self->data[pos] = val; \
  \
     Py_RETURN_NONE;
 
 #define TABLE_GET \
-    int pos; \
+    T_SIZE_T pos; \
     static char *kwlist[] = {"pos", NULL}; \
  \
-    if (! PyArg_ParseTupleAndKeywords(args, kwds, "i", kwlist, &pos)) \
+    if (! PyArg_ParseTupleAndKeywords(args, kwds, "n", kwlist, &pos)) \
         return PyInt_FromLong(-1); \
  \
-    if (pos >= self->size) { \
-        PyErr_SetString(PyExc_TypeError, "position outside of table boundaries!."); \
+    if (pos < -self->size || pos >= self->size) { \
+        PyErr_SetString(PyExc_IndexError, "PyoTableObject: Position outside of table boundaries!."); \
         return PyInt_FromLong(-1); \
     } \
+ \
+    if (pos < 0) \
+        pos = self->size + pos; \
  \
     return PyFloat_FromDouble(self->data[pos]);
 
+#define TABLE_SET_SIZE \
+    if (value == NULL) \
+    { \
+        PyErr_SetString(PyExc_TypeError, "Cannot delete the size attribute."); \
+        return PyInt_FromLong(-1); \
+    } \
+ \
+    if (! PyInt_Check(value)) \
+    { \
+        PyErr_SetString(PyExc_TypeError, "The size attribute value must be an integer."); \
+        return PyInt_FromLong(-1); \
+    } \
+ \
+    self->size = PyInt_AsLong(value); \
+ \
+    self->data = (MYFLT *)PyMem_RawRealloc(self->data, (self->size + 1) * sizeof(MYFLT)); \
+    TableStream_setSize(self->tablestream, self->size);
+
+#define TABLE_SET_SIZE_WITH_POINT_LIST \
+    T_SIZE_T i, old_size, x1; \
+    MYFLT factor; \
+    PyObject *tup, *x2; \
+ \
+    if (value == NULL) \
+    { \
+        PyErr_SetString(PyExc_TypeError, "Cannot delete the size attribute."); \
+        return PyInt_FromLong(-1); \
+    } \
+ \
+    if (! PyInt_Check(value)) \
+    { \
+        PyErr_SetString(PyExc_TypeError, "The size attribute value must be an integer."); \
+        return PyInt_FromLong(-1); \
+    } \
+ \
+    old_size = self->size; \
+    self->size = PyInt_AsLong(value); \
+ \
+    factor = (MYFLT)(self->size) / old_size; \
+ \
+    self->data = (MYFLT *)PyMem_RawRealloc(self->data, (self->size + 1) * sizeof(MYFLT)); \
+    TableStream_setSize(self->tablestream, self->size); \
+ \
+    T_SIZE_T listsize = PyList_Size(self->pointslist); \
+ \
+    PyObject *listtemp = PyList_New(0); \
+ \
+    for (i = 0; i < (listsize); i++) \
+    { \
+        tup = PyList_GET_ITEM(self->pointslist, i); \
+        PyObject *p1 = PyTuple_GET_ITEM(tup, 0); \
+        x1 = PyLong_AsLong(PyNumber_Long(p1)); \
+        PyObject *p2 = PyTuple_GET_ITEM(tup, 1); \
+        x2 = PyNumber_Float(p2); \
+        PyList_Append(listtemp, PyTuple_Pack(2, PyLong_FromLong((T_SIZE_T)(x1 * factor)), x2)); \
+        Py_DECREF(p1); \
+        Py_DECREF(p2); \
+    } \
+ \
+    Py_INCREF(listtemp); \
+    Py_DECREF(self->pointslist); \
+    self->pointslist = listtemp;
+
 /* Matrix macros */
 #define MATRIX_BLUR \
     int i,j; \
@@ -1314,8 +1519,7 @@ extern PyTypeObject MMLZStreamType;
             self->data[i][j] = (tmp[i-1][j] + tmp[i][j] + tmp[i+1][j]) * 0.3333333; \
         } \
     } \
-    Py_INCREF(Py_None); \
-    return Py_None;
+    Py_RETURN_NONE;
 
 #define MATRIX_BOOST \
     int i, j; \
@@ -1336,8 +1540,7 @@ extern PyTypeObject MMLZStreamType;
             self->data[i][j] = NewMatrix_clip(val + (val-mid) * boost, min, max); \
         } \
     } \
-    Py_INCREF(Py_None); \
-    return Py_None; \
+    Py_RETURN_NONE; \
 
 #define MATRIX_PUT \
     MYFLT val; \
@@ -1367,8 +1570,7 @@ extern PyTypeObject MMLZStreamType;
     else if (y == 0) \
         self->data[self->height][x] = self->data[y][x]; \
  \
-    Py_INCREF(Py_None); \
-    return Py_None; \
+    Py_RETURN_NONE; \
 
 #define MATRIX_GET \
     int x, y; \
@@ -1461,8 +1663,7 @@ extern PyTypeObject MMLZStreamType;
     PyObject *tmp, *streamtmp; \
  \
     if (arg == NULL) { \
-        Py_INCREF(Py_None); \
-        return Py_None; \
+        Py_RETURN_NONE; \
     } \
  \
     int isNumber = PyNumber_Check(arg); \
@@ -1480,6 +1681,7 @@ extern PyTypeObject MMLZStreamType;
             PyErr_SetString(PyExc_ArithmeticError, "Only number or audio internal object can be used in arithmetic with audio internal objects.\n"); \
             PyErr_Print(); \
         } \
+        Py_INCREF(self->mul); \
         streamtmp = PyObject_CallMethod((PyObject *)self->mul, "_getStream", NULL); \
         Py_INCREF(streamtmp); \
         Py_XDECREF(self->mul_stream); \
@@ -1489,15 +1691,13 @@ extern PyTypeObject MMLZStreamType;
  \
     (*self->mode_func_ptr)(self); \
  \
-    Py_INCREF(Py_None); \
-    return Py_None;
+    Py_RETURN_NONE;
 
 #define SET_ADD \
     PyObject *tmp, *streamtmp; \
 \
     if (arg == NULL) { \
-        Py_INCREF(Py_None); \
-        return Py_None; \
+        Py_RETURN_NONE; \
     } \
 \
     int isNumber = PyNumber_Check(arg); \
@@ -1515,6 +1715,7 @@ extern PyTypeObject MMLZStreamType;
             PyErr_SetString(PyExc_ArithmeticError, "Only number or audio internal object can be used in arithmetic with audio internal objects.\n"); \
             PyErr_Print(); \
         } \
+        Py_INCREF(self->add); \
         streamtmp = PyObject_CallMethod((PyObject *)self->add, "_getStream", NULL); \
         Py_INCREF(streamtmp); \
         Py_XDECREF(self->add_stream); \
@@ -1524,15 +1725,13 @@ extern PyTypeObject MMLZStreamType;
 \
     (*self->mode_func_ptr)(self); \
 \
-    Py_INCREF(Py_None); \
-    return Py_None;
+    Py_RETURN_NONE;
 
 #define SET_SUB \
     PyObject *tmp, *streamtmp; \
  \
     if (arg == NULL) { \
-        Py_INCREF(Py_None); \
-        return Py_None; \
+        Py_RETURN_NONE; \
     } \
  \
     int isNumber = PyNumber_Check(arg); \
@@ -1541,7 +1740,7 @@ extern PyTypeObject MMLZStreamType;
     Py_INCREF(tmp); \
     Py_DECREF(self->add); \
     if (isNumber == 1) { \
-        self->add = PyNumber_Multiply(PyNumber_Float(tmp), PyFloat_FromDouble(-1)); \
+        self->add = PyFloat_FromDouble(PyFloat_AsDouble(tmp) * -1.0); \
         self->modebuffer[1] = 0; \
     } \
     else { \
@@ -1550,6 +1749,7 @@ extern PyTypeObject MMLZStreamType;
             PyErr_SetString(PyExc_ArithmeticError, "Only number or audio internal object can be used in arithmetic with audio internal objects.\n"); \
             PyErr_Print(); \
         } \
+        Py_INCREF(self->add); \
         streamtmp = PyObject_CallMethod((PyObject *)self->add, "_getStream", NULL); \
         Py_INCREF(streamtmp); \
         Py_XDECREF(self->add_stream); \
@@ -1559,15 +1759,13 @@ extern PyTypeObject MMLZStreamType;
  \
     (*self->mode_func_ptr)(self); \
  \
-    Py_INCREF(Py_None); \
-    return Py_None;
+    Py_RETURN_NONE;
 
 #define SET_DIV \
     PyObject *tmp, *streamtmp; \
  \
     if (arg == NULL) { \
-        Py_INCREF(Py_None); \
-        return Py_None; \
+        Py_RETURN_NONE; \
     } \
  \
     int isNumber = PyNumber_Check(arg); \
@@ -1577,7 +1775,7 @@ extern PyTypeObject MMLZStreamType;
     if (isNumber == 1) { \
         if (PyFloat_AsDouble(tmp) != 0.) { \
             Py_DECREF(self->mul); \
-            self->mul = PyNumber_TrueDivide(PyFloat_FromDouble(1.), PyNumber_Float(tmp)); \
+            self->mul = PyFloat_FromDouble(1.0 / PyFloat_AsDouble(tmp)); \
             self->modebuffer[0] = 0; \
         } \
     } \
@@ -1588,6 +1786,7 @@ extern PyTypeObject MMLZStreamType;
             PyErr_SetString(PyExc_ArithmeticError, "Only number or audio internal object can be used in arithmetic with audio internal objects.\n"); \
             PyErr_Print(); \
         } \
+        Py_INCREF(self->mul); \
         streamtmp = PyObject_CallMethod((PyObject *)self->mul, "_getStream", NULL); \
         Py_INCREF(streamtmp); \
         Py_XDECREF(self->mul_stream); \
@@ -1597,8 +1796,7 @@ extern PyTypeObject MMLZStreamType;
  \
     (*self->mode_func_ptr)(self); \
  \
-    Py_INCREF(Py_None); \
-    return Py_None;
+    Py_RETURN_NONE;
 
 /* Multiply, Add, inplace_multiply & inplace_add */
 #define MULTIPLY \
@@ -1606,11 +1804,14 @@ extern PyTypeObject MMLZStreamType;
     MAKE_NEW_DUMMY(dummy, &DummyType, NULL); \
     Dummy_initialize(dummy); \
     PyObject_CallMethod((PyObject *)dummy, "setMul", "O", arg); \
+    Py_DECREF(arg); \
     PyObject_CallMethod((PyObject *)dummy, "setInput", "O", self); \
     return (PyObject *)dummy;
 
 #define INPLACE_MULTIPLY \
     PyObject_CallMethod((PyObject *)self, "setMul", "O", arg); \
+    Py_DECREF(arg); \
+    Py_INCREF(self); \
     return (PyObject *)self;
 
 #define ADD \
@@ -1618,11 +1819,14 @@ extern PyTypeObject MMLZStreamType;
     MAKE_NEW_DUMMY(dummy, &DummyType, NULL); \
     Dummy_initialize(dummy); \
     PyObject_CallMethod((PyObject *)dummy, "setAdd", "O", arg); \
+    Py_DECREF(arg); \
     PyObject_CallMethod((PyObject *)dummy, "setInput", "O", self); \
     return (PyObject *)dummy;
 
 #define INPLACE_ADD \
     PyObject_CallMethod((PyObject *)self, "setAdd", "O", arg); \
+    Py_DECREF(arg); \
+    Py_INCREF(self); \
     return (PyObject *)self;
 
 #define SUB \
@@ -1630,11 +1834,14 @@ extern PyTypeObject MMLZStreamType;
     MAKE_NEW_DUMMY(dummy, &DummyType, NULL); \
     Dummy_initialize(dummy); \
     PyObject_CallMethod((PyObject *)dummy, "setSub", "O", arg); \
+    Py_DECREF(arg); \
     PyObject_CallMethod((PyObject *)dummy, "setInput", "O", self); \
     return (PyObject *)dummy;
 
 #define INPLACE_SUB \
     PyObject_CallMethod((PyObject *)self, "setSub", "O", arg); \
+    Py_DECREF(arg); \
+    Py_INCREF(self); \
     return (PyObject *)self;
 
 #define DIV \
@@ -1642,11 +1849,14 @@ extern PyTypeObject MMLZStreamType;
     MAKE_NEW_DUMMY(dummy, &DummyType, NULL); \
     Dummy_initialize(dummy); \
     PyObject_CallMethod((PyObject *)dummy, "setDiv", "O", arg); \
+    Py_DECREF(arg); \
     PyObject_CallMethod((PyObject *)dummy, "setInput", "O", self); \
     return (PyObject *)dummy;
 
 #define INPLACE_DIV \
     PyObject_CallMethod((PyObject *)self, "setDiv", "O", arg); \
+    Py_DECREF(arg); \
+    Py_INCREF(self); \
     return (PyObject *)self;
 
 /* PLAY, OUT, STOP */
@@ -1663,8 +1873,12 @@ extern PyTypeObject MMLZStreamType;
     if (! PyArg_ParseTupleAndKeywords(args, kwds, "|ff", kwlist, &dur, &del)) \
         return PyInt_FromLong(-1); \
  \
-    globdel = PyFloat_AsDouble(PyObject_CallMethod(PyServer_get_server(), "getGlobalDel", NULL)); \
-    globdur = PyFloat_AsDouble(PyObject_CallMethod(PyServer_get_server(), "getGlobalDur", NULL)); \
+    PyObject *delobj = PyObject_CallMethod(self->server, "getGlobalDel", NULL); \
+    PyObject *durobj = PyObject_CallMethod(self->server, "getGlobalDur", NULL); \
+    globdel = PyFloat_AsDouble(delobj); \
+    globdur = PyFloat_AsDouble(durobj); \
+    Py_DECREF(delobj); \
+    Py_DECREF(durobj); \
  \
     if (globdel != 0) \
         del = globdel; \
@@ -1712,8 +1926,12 @@ extern PyTypeObject MMLZStreamType;
     if (! PyArg_ParseTupleAndKeywords(args, kwds, "|iff", kwlist, &chnltmp, &dur, &del)) \
         return PyInt_FromLong(-1); \
  \
-    globdel = PyFloat_AsDouble(PyObject_CallMethod(PyServer_get_server(), "getGlobalDel", NULL)); \
-    globdur = PyFloat_AsDouble(PyObject_CallMethod(PyServer_get_server(), "getGlobalDur", NULL)); \
+    PyObject *delobj = PyObject_CallMethod(self->server, "getGlobalDel", NULL); \
+    PyObject *durobj = PyObject_CallMethod(self->server, "getGlobalDur", NULL); \
+    globdel = PyFloat_AsDouble(delobj); \
+    globdur = PyFloat_AsDouble(durobj); \
+    Py_DECREF(delobj); \
+    Py_DECREF(durobj); \
  \
     if (globdel != 0) \
         del = globdel; \
@@ -1727,11 +1945,17 @@ extern PyTypeObject MMLZStreamType;
         Stream_setStreamActive(self->stream, 1); \
     } \
     else { \
-        Stream_setStreamActive(self->stream, 0); \
-        for (i=0; i<self->bufsize; i++) \
-            self->data[i] = 0.0; \
         nearestBuf = (int)roundf((del * self->sr) / self->bufsize); \
-        Stream_setBufferCountWait(self->stream, nearestBuf); \
+        if (nearestBuf <= 0) { \
+            Stream_setBufferCountWait(self->stream, 0); \
+            Stream_setStreamActive(self->stream, 1); \
+        } \
+        else { \
+            Stream_setStreamActive(self->stream, 0); \
+            for (i=0; i<self->bufsize; i++) \
+                self->data[i] = 0.0; \
+            Stream_setBufferCountWait(self->stream, nearestBuf); \
+        } \
     } \
     if (dur == 0) \
         Stream_setDuration(self->stream, 0); \
@@ -1764,8 +1988,7 @@ extern PyTypeObject MMLZStreamType;
         nearestBuf = (int)roundf((wait * self->sr) / self->bufsize + 0.5); \
         Stream_setDuration(self->stream, nearestBuf); \
     } \
-    Py_INCREF(Py_None); \
-    return Py_None;
+    Py_RETURN_NONE;
 
 /* Post processing (mul & add) macros */
 #define POST_PROCESSING_II \
@@ -1913,3 +2136,5 @@ extern PyTypeObject MMLZStreamType;
     view->internal = NULL; \
     Py_INCREF(self); \
     return 0;
+
+#endif // _PYOMODULE_H
\ No newline at end of file
